@@ -24,3 +24,7 @@ class HTTPError(FacepyError):
 
 class SignedRequestError(FacepyError):
     """Exception for invalid signed requests."""
+
+
+class InternalFacebookError(FacebookError):
+    """Exception for Facebook internal server error."""
